<?php

namespace App\Http\Controllers;

use App\Models\SuratDukungan;
use App\Models\UserLog;
use Exception;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class SuratDukunganController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $title = "Surat Dukungan";
        $link = "surat-dukungan";
        $parent = "Master Data";

        $s = '';
        $page = 1;

        if(isset($_GET['s'])){
            $s = $_GET['s'];
        }

        if(isset($_GET['page'])){
            $page = $_GET['page'];
        }

        $datas = SuratDukungan::orderBy('tanggal','DESC');
        if(isset($_GET['periode']) && $_GET['periode'] != null && $_GET['periode'] != ''){
            $periode = explode(' - ', $_GET['periode']);
            $datas = $datas->whereDate('tanggal','>=',date('Y-m-d',strtotime($periode[0])))->whereDate('tanggal','<=',date('Y-m-d',strtotime($periode[1])))->paginate(10);
        } else {
            $datas = $datas->paginate(10);
        }
        $datas->appends($_GET);
        $no = 1*$page*10-10+1;
        // return view('kecamatan.index',compact('title','kecamatan','parent','link','datas','no'));
        return view('surat-dukungan.index',compact('title','parent','link','datas','no'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $title = "Tambah Data Surat Dukungan";
        $link = "surat-dukungan";
        $parent = "kabupaten";

        // return view('kecamatan.create',compact('title','kecamatan','parent','link'));
        return view('surat-dukungan.create',compact('title','parent','link'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        try {
            $request->validate([
                'tanggal' => 'required',
                // 'surduk_keluar' => 'required',
                // 'surduk_masuk' => 'required',
            ]);
            // dd(Kabupaten::get());
            $data = new SuratDukungan();
            $data->tanggal = $request->tanggal;
            $data->surduk_keluar = $request->surduk_keluar ? $request->surduk_keluar : 0;
            $data->surduk_masuk = $request->surduk_masuk ? $request->surduk_masuk : 0;
            $data->save();
            $msg = 'Berhasil menambah data surat dukungan tanggal '. date('d/m/Y', strtotime($data->tanggal));
            UserLog::create(['user_id'=>Auth::user()->id,'keterangan'=>$msg]);
            return redirect('surat-dukungan')->with('success_message', $msg);
        } catch (Exception $e) {
            return redirect('surat-dukungan')->with('error_message', "Gagal di tambah");
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $title = "Edit Data Surat Dukungan";
        $link = "surat-dukungan";
        $parent = "surat-dukungan";
        $data = SuratDukungan::find($id);
        // return view('kecamatan.edit',compact('title','kecamatan','parent','link','data'));
        return view('surat-dukungan.edit',compact('title','parent','link','data'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $data = SuratDukungan::find($id);
        $data->tanggal = $request->tanggal;
        $data->surduk_keluar = $request->surduk_keluar ? $request->surduk_keluar : 0;
        $data->surduk_masuk = $request->surduk_masuk ? $request->surduk_masuk : 0;
        $data->save();
        $msg = 'Berhasil mengubah data surat dukungan tanggal '. date('d/m/Y', strtotime($data->tanggal));
        UserLog::create(['user_id'=>Auth::user()->id,'keterangan'=>$msg]);
        return redirect('surat-dukungan')->with('success_message', $msg);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        try {
            $data = SuratDukungan::find($id);
            $data->delete();
            $msg = 'Berhasil menghapus data surat dukungan tanggal '. date('d/m/Y', strtotime($data->tanggal));
            UserLog::create(['user_id'=>Auth::user()->id,'keterangan'=>$msg]);
            return redirect('surat-dukungan')->with('success_message', $msg);
        } catch (Exception $e) {
            return redirect('surat-dukungan')->with('error_message', "Gagal dihapus");
        }
    }
}
